@@ -21,7 +21,7 @@ extern const unsigned char qmlData alignas(16) [];
 extern const unsigned char qmlData alignas(16) [] = {
 
 0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
-0x47,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
+0x48,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
 0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
 0x24,0x21,0x0,0x0,0xd9,0xcf,0x54,0x71,
 0x5f,0x89,0xb1,0x58,0x4a,0xc9,0x8f,0xac,
@@ -1424,7 +1424,7 @@ return;
 }
 }
 {
-s.c2_16 = std::move(s.v2_14);
+s.c2_16 = s.v2_14;
 }
 label_1:;
 {
@@ -1591,7 +1591,7 @@ return;
 }
 }
 {
-s.c2_16 = std::move(s.v2_14);
+s.c2_16 = s.v2_14;
 }
 label_1:;
 {
@@ -1782,7 +1782,7 @@ s.v2_21 = double(0);
 // generate_CmpGt
 s.v2_22 = s.v2_17 > s.v2_21;
 {
-s.c2_24 = std::move(s.v2_22);
+s.c2_24 = s.v2_22;
 }
 label_0:;
 {
@@ -1952,7 +1952,7 @@ label_0:;
 // generate_LoadRuntimeString
 s.v2_26 = QUrl(QStringLiteral(""));
 {
-s.c2_28 = std::move(s.v2_26);
+s.c2_28 = s.v2_26;
 }
 label_1:;
 {
