@@ -25,7 +25,7 @@ extern const unsigned char qmlData alignas(16) [];
 extern const unsigned char qmlData alignas(16) [] = {
 
 0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
-0x47,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
+0x48,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
 0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
 0xc8,0x1c,0x0,0x0,0x37,0xcc,0xbd,0x1d,
 0x3c,0xed,0x61,0xe3,0xa5,0xce,0x5b,0x5c,
@@ -1522,7 +1522,7 @@ s.v2_24 = double(0);
 // generate_CmpGt
 s.v2_25 = s.v2_20 > s.v2_24;
 {
-s.c2_27 = std::move(s.v2_25);
+s.c2_27 = s.v2_25;
 }
 label_1:;
 // generate_JumpTrue
@@ -1610,7 +1610,7 @@ s.v2_39 = double(0);
 // generate_CmpGt
 s.v2_40 = s.v2_35 > s.v2_39;
 {
-s.c2_42 = std::move(s.v2_40);
+s.c2_42 = s.v2_40;
 }
 label_0:;
 {
@@ -1768,7 +1768,7 @@ return;
 // generate_Div
 s.v2_20 = (s.v2_14 / s.v2_18);
 {
-s.c2_22 = std::move(s.v2_20);
+s.c2_22 = s.v2_20;
 }
 label_1:;
 {
@@ -1911,7 +1911,7 @@ s.v2_20 = double(1);
 // generate_CmpLt
 s.v2_22 = s.v2_16 < s.v2_20;
 {
-s.c2_24 = std::move(s.v2_22);
+s.c2_24 = s.v2_22;
 }
 label_0:;
 {
@@ -2057,7 +2057,7 @@ return;
 }
 }
 {
-s.c2_14 = std::move(s.v2_12);
+s.c2_14 = s.v2_12;
 }
 label_0:;
 {
@@ -2182,7 +2182,7 @@ return;
 }
 }
 {
-s.v7_12 = std::move(s.v2_10);
+s.v7_12 = s.v2_10;
 }
 label_1:;
 // generate_StoreReg
@@ -2312,7 +2312,7 @@ return;
 }
 }
 {
-s.c2_10 = std::move(s.v2_8);
+s.c2_10 = s.v2_8;
 }
 label_0:;
 {
@@ -2437,7 +2437,7 @@ return;
 }
 }
 {
-s.v7_12 = std::move(s.v2_10);
+s.v7_12 = s.v2_10;
 }
 label_1:;
 // generate_StoreReg
